summaryrefslogtreecommitdiffstats
path: root/cli/src/cli-cmd-parser.c
diff options
context:
space:
mode:
Diffstat (limited to 'cli/src/cli-cmd-parser.c')
-rw-r--r--cli/src/cli-cmd-parser.c32
1 files changed, 16 insertions, 16 deletions
diff --git a/cli/src/cli-cmd-parser.c b/cli/src/cli-cmd-parser.c
index f14fc702c..5e23d87f8 100644
--- a/cli/src/cli-cmd-parser.c
+++ b/cli/src/cli-cmd-parser.c
@@ -2816,7 +2816,7 @@ out :
-/* snapshot create <snap-name> <vol-name(s)> [description <description>]
+/* snapshot create <snapname> <vol-name(s)> [description <description>]
* [force]
* @arg-0, dict : Request Dictionary to be sent to server side.
* @arg-1, words : Contains individual words of CLI command.
@@ -3023,20 +3023,20 @@ cli_snap_info_parse (dict_t *dict, const char **words, int wordcount,
}
/* If 3rd word is not "volume", then it must
- * be snap-name.
+ * be snapname.
*/
if (strcmp (words[cmdi], "volume") != 0) {
ret = dict_set_str (dict, "snapname",
(char *)words[cmdi]);
if (ret) {
gf_log ("cli", GF_LOG_ERROR, "Unable to save "
- "snap-name %s", words[cmdi]);
+ "snapname %s", words[cmdi]);
goto out;
}
/* Once snap name is parsed, if we encounter any other
* word then fail it. Invalid Syntax.
* example : snapshot info <snap-name> word
*/
if ((cmdi + 1) != wordcount) {
ret = -1;
@@ -3047,7 +3047,7 @@ cli_snap_info_parse (dict_t *dict, const char **words, int wordcount,
ret = 0;
goto out;
/* No need to continue the parsing once we
- * get the snap-name
+ * get the snapname
*/
}
@@ -3266,9 +3266,9 @@ cli_snap_remove_parse (dict_t *dict, const char **words, int wordcount,
}
}
/* Saving snap-name/cg-name in dict */
if (name_opt_loc >= cmdi) {
/* Decide if it's a cg-name or a snap-name */
if (is_cg) {
ret = dict_set_str (dict, "cgname",
(char *)words[name_opt_loc + 1]);
@@ -3313,7 +3313,7 @@ out:
}
/* Syntax:
- * snapshot restore (-v <volname> <snap-name> | -c <cg-name> )
+ * snapshot restore (-v <volname> <snapname> | -c <cg-name> )
*/
int
cli_snap_restore_parse (dict_t *dict, const char **words, int wordcount,
@@ -3334,7 +3334,7 @@ cli_snap_restore_parse (dict_t *dict, const char **words, int wordcount,
goto out;
}
if (0 == strcmp (words[cmdi], "-v")) {
- /* snapshot restore -v <volname> <snap-name>
+ /* snapshot restore -v <volname> <snapname>
*
* cmdi points to -v, therefore wordcount should be exactly
* equal to (cmdi + 2) + 1. +1 is added to convert index to
@@ -3437,9 +3437,9 @@ cli_snap_delete_parse (dict_t *dict, const char **words, int wordcount,
goto out;
}
- ret = dict_set_str (dict, "snap-name", (char *)words[cmdi]);
+ ret = dict_set_str (dict, "snapname", (char *)words[cmdi]);
if (ret) {
- gf_log ("cli", GF_LOG_ERROR, "Unable to save snap-name %s",
+ gf_log ("cli", GF_LOG_ERROR, "Unable to save snapname %s",
words[cmdi]);
goto out;
}
@@ -3511,12 +3511,12 @@ cli_cmd_snapshot_parse (const char **words, int wordcount, dict_t **options,
case GF_SNAP_OPTION_TYPE_CREATE:
{
/* Syntax :
* gluster snapshot create <snap-name> <vol-name(s)>
* [description <description>]
* [force]
*/
/* In cases where the snap-name is not given then
* parsing fails & snapname cannot be an opword,
* that check is made here
*/
@@ -3536,7 +3536,7 @@ cli_cmd_snapshot_parse (const char **words, int wordcount, dict_t **options,
case GF_SNAP_OPTION_TYPE_INFO:
{
/* Syntax :
* gluster snapshot info ([snap-name] | [vol <volname>])
*/
ret = cli_snap_info_parse (dict, words, wordcount,
cmdi);
@@ -3567,7 +3567,7 @@ cli_cmd_snapshot_parse (const char **words, int wordcount, dict_t **options,
case GF_SNAP_OPTION_TYPE_DELETE:
{
/* Syntax :
* gluster snapshot delete <snap-name>
*/
ret = cli_snap_delete_parse (dict, words, wordcount,
cmdi, state);
@@ -3596,7 +3596,7 @@ cli_cmd_snapshot_parse (const char **words, int wordcount, dict_t **options,
case GF_SNAP_OPTION_TYPE_RESTORE:
{
/* Syntax:
- * snapshot restore (-v <volname> <snap-name> |
+ * snapshot restore (-v <volname> <snapname> |
* -c <cg-name> )
*/
@@ -3023,20 +3023,20 @@ cli_snap_info_parse (dict_t *dict, const char **words, int wordcount,
/* Once snap name is parsed, if we encounter any other
* word then fail it. Invalid Syntax.
- * example : snapshot info <snap-name> word
+ * example : snapshot info <snapname> word
*/
if ((cmdi + 1) != wordcount) {
@@ -3266,9 +3266,9 @@ cli_snap_remove_parse (dict_t *dict, const char **words, int wordcount,
}
}
- /* Saving snap-name/cg-name in dict */
+ /* Saving snapname/cg-name in dict */
if (name_opt_loc >= cmdi) {
@@ -3266,9 +3266,9 @@ cli_snap_remove_parse (dict_t *dict, const char **words, int wordcount,
if (name_opt_loc >= cmdi) {
- /* Decide if it's a cg-name or a snap-name */
+ /* Decide if it's a cg-name or a snapname */
if (is_cg) {
ret = dict_set_str (dict, "cgname",
@@ -3511,12 +3511,12 @@ cli_cmd_snapshot_parse (const char **words, int wordcount, dict_t **options,
{
/* Syntax :
- * gluster snapshot create <snap-name> <vol-name(s)>
+ * gluster snapshot create <snapname> <vol-name(s)>
* [description <description>]
* [force]
@@ -3511,12 +3511,12 @@ cli_cmd_snapshot_parse (const char **words, int wordcount, dict_t **options,
* [force]
*/
- /* In cases where the snap-name is not given then
+ /* In cases where the snapname is not given then
* parsing fails & snapname cannot be an opword,
* that check is made here
@@ -3536,7 +3536,7 @@ cli_cmd_snapshot_parse (const char **words, int wordcount, dict_t **options,
{
/* Syntax :
- * gluster snapshot info ([snap-name] | [vol <volname>])
+ * gluster snapshot info ([snapname] | [vol <volname>])
*/
ret = cli_snap_info_parse (dict, words, wordcount,
@@ -3567,7 +3567,7 @@ cli_cmd_snapshot_parse (const char **words, int wordcount, dict_t **options,
{
/* Syntax :
- * gluster snapshot delete <snap-name>
+ * gluster snapshot delete <snapname>
*/
ret = cli_snap_delete_parse (dict, words, wordcount,